@@ -1,5 +1,5 @@
 package Evo::Ee;
-use Evo '-Comp::Role *';
+use Evo '-Role *';
 use Carp 'croak';
 use List::Util 'first';
 
@@ -49,7 +49,7 @@ Evo::Ee
 
 =head1 VERSION
 
-version 0.0187
+version 0.0188
 
 =head1 DESCRIPTION
 
