@@ -1,5 +1,5 @@
 package Evo::Loop;
-use Evo '-Realm *; -Export *; -Realm *';
+use Evo '-Realm *; -Export *';
 use Evo ':Comp';
 
 use constant DEFAULT => Evo::Loop::Comp::new();
@@ -32,7 +32,7 @@ Evo::Loop
 
 =head1 VERSION
 
-version 0.0187
+version 0.0188
 
 =head1 AUTHOR
 
