@@ -1,5 +1,5 @@
 package Evo::Loop::Role::Handle;
-use Evo '-Comp::Role *';
+use Evo '-Role *';
 use Carp 'croak';
 use IO::Poll qw(POLLERR POLLHUP POLLIN POLLNVAL POLLOUT POLLPRI);
 
@@ -95,7 +95,7 @@ Evo::Loop::Role::Handle
 
 =head1 VERSION
 
-version 0.0187
+version 0.0188
 
 =head1 AUTHOR
 
