@@ -1,5 +1,5 @@
 package Evo::Loop::Role::Postpone;
-use Evo '-Comp::Role *';
+use Evo '-Role *';
 
 requires qw(zone_cb);
 
@@ -27,7 +27,7 @@ Evo::Loop::Role::Postpone
 
 =head1 VERSION
 
-version 0.0187
+version 0.0188
 
 =head1 AUTHOR
 
