@@ -1,5 +1,5 @@
 package Evo::Loop::Role::Timer;
-use Evo '-Comp::Role *';
+use Evo '-Role *';
 use List::Util 'first';
 
 requires qw(zone_cb tick_time);
@@ -67,7 +67,7 @@ Evo::Loop::Role::Timer
 
 =head1 VERSION
 
-version 0.0187
+version 0.0188
 
 =head1 AUTHOR
 
