@@ -1,5 +1,5 @@
 package Evo::Net::Socket::Role;
-use Evo '-Comp::Role *; -Net::Util *; Symbol gensym; Carp croak';
+use Evo '-Role *; -Net::Util *; Symbol gensym; Carp croak';
 use Socket qw(
   SOCK_STREAM AF_INET AF_INET6 SOL_SOCKET IPPROTO_TCP TCP_NODELAY
   SO_REUSEADDR SO_REUSEPORT SO_DOMAIN SO_TYPE SO_PROTOCOL SO_SNDBUF SO_RCVBUF
@@ -80,7 +80,7 @@ Evo::Net::Socket::Role
 
 =head1 VERSION
 
-version 0.0187
+version 0.0188
 
 =head1 AUTHOR
 
