@@ -1,5 +1,5 @@
 package Evo::Promises::Promise::Driver;
-use Evo '-Comp::Role *; -Promises::Sync; -Promises::Util FULFILLED REJECTED PENDING';
+use Evo '-Role *; -Promises::Sync; -Promises::Util FULFILLED REJECTED PENDING';
 use Carp 'croak';
 use Scalar::Util 'blessed';
 
@@ -159,7 +159,7 @@ Evo::Promises::Promise::Driver
 
 =head1 VERSION
 
-version 0.0187
+version 0.0188
 
 =head1 AUTHOR
 
